changeset 71155:c4f7808cbe56

(hack-local-variables-prop-line): Ignore `char-trans' as well as `coding'.
author Kenichi Handa <handa@m17n.org>
date Fri, 02 Jun 2006 06:28:13 +0000
parents cb001b5b571b
children bb2f67aa85f1
files lisp/files.el
diffstat 1 files changed, 3 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/files.el	Fri Jun 02 03:54:14 2006 +0000
+++ b/lisp/files.el	Fri Jun 02 06:28:13 2006 +0000
@@ -2487,10 +2487,12 @@
 		 ;; case when checking for `mode' in set-auto-mode,
 		 ;; so we must do that here as well.
 		 ;; That is inconsistent, but we're stuck with it.
 		 ;; The same can be said for `coding' in set-auto-coding.
 		 (or (and (equal (downcase (symbol-name key)) "mode")
 			  (setq mode-specified t))
 		     (equal (downcase (symbol-name key)) "coding")
+		     (equal (downcase (symbol-name key)) "char-trans")
 		     (condition-case nil
 			 (push (cons (if (eq key 'eval)
 					 'eval
@@ -2487,10 +2487,12 @@
 		 ;; so we must do that here as well.
 		 ;; That is inconsistent, but we're stuck with it.
-		 ;; The same can be said for `coding' in set-auto-coding.
+		 ;; The same can be said for `coding' and `char-trans'
+		 ;; in set-auto-coding.
 		 (or (and (equal (downcase (symbol-name key)) "mode")
 			  (setq mode-specified t))